aboutsummaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
Diffstat (limited to 'tests')
-rw-r--r--tests/account_test.go8
1 files changed, 5 insertions, 3 deletions
diff --git a/tests/account_test.go b/tests/account_test.go
index 2885bfa..f5925f0 100644
--- a/tests/account_test.go
+++ b/tests/account_test.go
@@ -32,9 +32,11 @@ func TestAccountBasic(t *testing.T) {
}
//There are not a lot of things we can test here (besides testing that
//Headers() does not fail, i.e. everything parses correctly), but
- //Content-Type is going to be text/plain because GET on an account lists
- //the container names as plain text.
- expectString(t, hdr.Get("Content-Type"), "text/plain; charset=utf-8")
+ //Content-Type is going to be either application/json or text/plain because
+ //GET on an account lists the container names as plain text or JSON.
+ if hdr.Get("Content-Type") != "application/json; charset=utf-8" {
+ expectString(t, hdr.Get("Content-Type"), "text/plain; charset=utf-8")
+ }
})
}